bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGamma.has_plotter
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGamma.has_plotter